The statnetWeb package makes it easy to run descriptive statistics, graphics and statistical analyses of network data via an intuitive graphical user interface. It is an Rshiny application based on the Statnet suite of network analysis packages See https://statnet.org for more information.
Maintainer: Martina Morris morrism@uw.edu
Authors:
Emily Beylerian ebeylerian@path.org
Other contributors:
Kirk Li kirkli@uw.edu [contributor]
Samuel Jenness samuel.m.jenness@emory.edu [contributor]
Michał Bojanowski michal2992@gmail.com (ORCID) [contributor]
Useful links: